==> streamroller-3.0.4.tgz: package/CHANGELOG.md <==
# streamroller Changelog

## 3.0.4

- [test: remove test file/folder remnants](https://github.com/log4js-node/streamroller/pull/99) - thanks [@peteriman](https://github.com/peteriman)

## 3.0.3

- [compat: backward compatibility for RollingFileWriteStream to recursively create directory](https://github.com/log4js-node/streamroller/pull/96) - thanks [@peteriman](https://github.com/peteriman)
- [test: 100% test coverage](https://github.com/log4js-node/streamroller/pull/94) - thanks [@peteriman](https://github.com/peteriman)
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/97) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump @commitlint/cli from 16.1.0 to 16.2.1
  - chore(deps-dev): bump @commitlint/config-conventional from 16.0.0 to … 
  - chore(deps-dev): bump @types/node from 17.0.16 to 17.0.21
  - chore(deps-dev): bump eslint from 8.8.0 to 8.10.0
  - chore(deps-dev): bump mocha from 9.2.0 to 9.2.1
  - chore(deps): bump date-format from 4.0.3 to 4.0.4
  - chore(deps): bump fs-extra from 10.0.0 to 10.0.1
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/95) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump @commitlint/cli from 16.0.2 to 16.1.0
  - chore(deps-dev): bump @types/node from 17.0.9 to 17.0.16
  - chore(deps-dev): bump eslint from 8.7.0 to 8.8.0
  - chore(deps-dev): bump proxyquire from 2.1.1 to 2.1.3
  - chore(deps): bump debug from 4.1.1 to 4.3.3
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/92) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps): updated package-lock.json 
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/91) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump mocha from 9.1.4 to 9.2.0

## 3.0.2

- [Changed default file modes from 0o644 to 0o600 for better security](https://github.com/log4js-node/streamroller/pull/87) - thanks [@peteriman](https://github.com/peteriman)
- [Housekeeping for comments and .gitignore](https://github.com/log4js-node/streamroller/pull/89) - thanks [@peteriman](https://github.com/peteriman)
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/88) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump caniuse-lite from 1.0.30001299 to 1.0.30001300
  - chore(deps-dev): bump electron-to-chromium from 1.4.45 to 1.4.47
  - chore(deps-dev): bump @types/node from 17.0.8 to 17.0.9
  - chore(deps-dev): bump eslint from 8.6.0 to 8.7.0
  - chore(deps-dev): bump mocha from 9.1.3 to 9.1.4
  - chore(deps): bump date-format from 4.0.2 to 4.0.3

## 3.0.1

- [Not to publish misc files to NPM](https://github.com/log4js-node/streamroller/pull/82) - thanks [@peteriman](https://github.com/peteriman)
- Updated dependencies - thanks [@peteriman](https://github.com/peteriman)
  - [date-format from 4.0.1 to 4.0.2](https://github.com/log4js-node/streamroller/pull/86)
  - [electron-to-chromium from 1.4.44 to 1.4.45](https://github.com/log4js-node/streamroller/pull/81) 

## 3.0.0

- [Fix for mode to apply to compressed file](https://github.com/log4js-node/streamroller/pull/65) - thanks [@rnd-debug](https://github.com/rnd-debug)
- [Allow for 0 backups (only hot file)](https://github.com/log4js-node/streamroller/pull/74) - thanks [@peteriman](https://github.com/peteriman)
- [Exposed fileNameSep to be configurable](https://github.com/log4js-node/streamroller/pull/67) - thanks [@laidaxian](https://github.com/laidaxian)
  - [Fix for fileNameSep affecting globally](https://github.com/log4js-node/streamroller/pull/79) - thanks [@peteriman](https://github.com/peteriman)
- [Fix for extra separator in filenames](https://github.com/log4js-node/streamroller/pull/75) - thanks [@peteriman](https://github.com/peteriman)
- [Moved to options.numBackups instead of options.daysToKeep](https://github.com/log4js-node/streamroller/pull/78) - thanks [@peteriman](https://github.com/peteriman)
- [Improved test case performance for fakeNow](https://github.com/log4js-node/streamroller/pull/76) - thanks [@peteriman](https://github.com/peteriman)
- <details><summary>Updated dependencies (click for details) - thanks <a href="https://github.com/peteriman">@peteriman</a></summary>
  
  - [package.json](https://github.com/log4js-node/streamroller/pull/70)
    - @commitlint/cli from 8.1.0 to 16.0.2
    - @commitlint/config-conventional from 8.1.0 to 16.0.0
    - @type/nodes 17.0.8
    - eslint from 6.0.1 to 8.6.0
    - mocha from 6.1.4 to 9.1.3
    - nyc from 14.1.1 to 15.1.0
  - [package-lock.json](https://github.com/log4js-node/streamroller/pull/71) 
    - @babel/compat-data from 7.16.4 to 7.16.8 
    - @babel/generator from 7.16.7 to 7.16.8
    - @babel/parser from 7.16.7 to 7.16.8
    - @babel/travers from 7.16.7 to 7.16.8
    - @babel/types from 7.16.7 to 7.16.8
  - [package-lock.json](https://github.com/log4js-node/streamroller/pull/77)
    - caniuse-lite from 1.0.30001298 to 1.0.30001299
    - electron-to-chromium from 1.4.39 to 1.4.44
  - [package.json](https://github.com/log4js-node/streamroller/pull/80)
    - date-format from 3.0.0 to 4.0.1
    - husky from 3.0.0 to 7.0.4
    - fs-extra from 8.1.0 to 10.0.0
</details>

## 2.2.4

- [Fix for incorrect filename matching](https://github.com/log4js-node/streamroller/pull/61) - thanks [@rnd-debug](https://github.com/rnd-debug)

## 2.2.3

- [Fix for unhandled promise rejection during cleanup](https://github.com/log4js-node/streamroller/pull/56)

## 2.2.2

- [Fix for overwriting current file when using date rotation](https://github.com/log4js-node/streamroller/pull/54)

## 2.2.1

- Fix for num to keep not working when date pattern is all digits (forgot to do a PR for this one)

## 2.2.0

- [Fallback to copy and truncate when file is busy](https://github.com/log4js-node/streamroller/pull/53)

## 2.1.0

- [Improve Windows support (closing streams)](https://github.com/log4js-node/streamroller/pull/52)

## 2.0.0

- [Remove support for node v6](https://github.com/log4js-node/streamroller/pull/44)
- [Replace lodash with native alternatives](https://github.com/log4js-node/streamroller/pull/45) - thanks [@devoto13](https://github.com/devoto13)
- [Simplify filename formatting and parsing](https://github.com/log4js-node/streamroller/pull/46)
- [Removed async lib from main code](https://github.com/log4js-node/streamroller/pull/47)
- [Fix timezone issues in tests](https://github.com/log4js-node/streamroller/pull/48) - thanks [@devoto13](https://github.com/devoto13)
- [Fix for flag values that need existing file size](https://github.com/log4js-node/streamroller/pull/49)
- [Refactor for better readability](https://github.com/log4js-node/streamroller/pull/50)
- [Removed async lib from test code](https://github.com/log4js-node/streamroller/pull/51)

## 1.0.6

- [Fix for overwriting old backup files](https://github.com/log4js-node/streamroller/pull/43)
- Updated lodash to 4.17.14

## 1.0.5

- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/38)
- [Fix for initial file date when appending to existing file](https://github.com/log4js-node/streamroller/pull/40)

## 1.0.4

- [Fix for initial size when appending to existing file](https://github.com/log4js-node/streamroller/pull/35)

## 1.0.3

- [Fix for crash when pattern is all digits](https://github.com/log4js-node/streamroller/pull/33)

## 1.0.2

- is exactly the same as 1.0.1, due to me being an idiot and not pulling before I pushed

## Previous versions

Previous release details are available by browsing the milestones in github.

==> streamroller-3.0.5.tgz: package/CHANGELOG.md <==
# streamroller Changelog

## 3.0.5

- [chore(validation): added filename validation](https://github.com/log4js-node/streamroller/pull/101) - thanks [@peteriman](https://github.com/peteriman)
- [chore(dep): updated dependencies](https://github.com/log4js-node/streamroller/pull/109) - thanks [@peteriman](https://github.com/peteriman)
  - eslint from 8.10.0 to 8.11.0
  - mocha from 9.2.1 to 9.2.2
  - date-format from 4.0.4 to 4.0.5
  - package-lock.json
- [chore(docs): updated README.md with badges](https://github.com/log4js-node/streamroller/pull/105) - thanks [@peteriman](https://github.com/peteriman)
- [chore(docs): updated README.md for DateRollingFileStream](https://github.com/log4js-node/streamroller/pull/106) - thanks [@peteriman](https://github.com/peteriman)
- [chore(docs): added docs for istanbul ignore](https://github.com/log4js-node/streamroller/pull/107) - thanks [@peteriman](https://github.com/peteriman)

## 3.0.4

- [test: remove test file/folder remnants](https://github.com/log4js-node/streamroller/pull/99) - thanks [@peteriman](https://github.com/peteriman)

## 3.0.3

- [compat: backward compatibility for RollingFileWriteStream to recursively create directory](https://github.com/log4js-node/streamroller/pull/96) - thanks [@peteriman](https://github.com/peteriman)
- [test: 100% test coverage](https://github.com/log4js-node/streamroller/pull/94) - thanks [@peteriman](https://github.com/peteriman)
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/97) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump @commitlint/cli from 16.1.0 to 16.2.1
  - chore(deps-dev): bump @commitlint/config-conventional from 16.0.0 to 16.2.1
  - chore(deps-dev): bump @types/node from 17.0.16 to 17.0.21
  - chore(deps-dev): bump eslint from 8.8.0 to 8.10.0
  - chore(deps-dev): bump mocha from 9.2.0 to 9.2.1
  - chore(deps): bump date-format from 4.0.3 to 4.0.4
  - chore(deps): bump fs-extra from 10.0.0 to 10.0.1
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/95) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump @commitlint/cli from 16.0.2 to 16.1.0
  - chore(deps-dev): bump @types/node from 17.0.9 to 17.0.16
  - chore(deps-dev): bump eslint from 8.7.0 to 8.8.0
  - chore(deps-dev): bump proxyquire from 2.1.1 to 2.1.3
  - chore(deps): bump debug from 4.1.1 to 4.3.3
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/92) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps): updated package-lock.json 
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/91) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump mocha from 9.1.4 to 9.2.0

## 3.0.2

- [Changed default file modes from 0o644 to 0o600 for better security](https://github.com/log4js-node/streamroller/pull/87) - thanks [@peteriman](https://github.com/peteriman)
- [Housekeeping for comments and .gitignore](https://github.com/log4js-node/streamroller/pull/89) - thanks [@peteriman](https://github.com/peteriman)
- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/88) - thanks [@peteriman](https://github.com/peteriman)
  - chore(deps-dev): bump caniuse-lite from 1.0.30001299 to 1.0.30001300
  - chore(deps-dev): bump electron-to-chromium from 1.4.45 to 1.4.47
  - chore(deps-dev): bump @types/node from 17.0.8 to 17.0.9
  - chore(deps-dev): bump eslint from 8.6.0 to 8.7.0
  - chore(deps-dev): bump mocha from 9.1.3 to 9.1.4
  - chore(deps): bump date-format from 4.0.2 to 4.0.3

## 3.0.1

- [Not to publish misc files to NPM](https://github.com/log4js-node/streamroller/pull/82) - thanks [@peteriman](https://github.com/peteriman)
- Updated dependencies - thanks [@peteriman](https://github.com/peteriman)
  - [date-format from 4.0.1 to 4.0.2](https://github.com/log4js-node/streamroller/pull/86)
  - [electron-to-chromium from 1.4.44 to 1.4.45](https://github.com/log4js-node/streamroller/pull/81) 

## 3.0.0

- [Fix for mode to apply to compressed file](https://github.com/log4js-node/streamroller/pull/65) - thanks [@rnd-debug](https://github.com/rnd-debug)
- [Allow for 0 backups (only hot file)](https://github.com/log4js-node/streamroller/pull/74) - thanks [@peteriman](https://github.com/peteriman)
- [Exposed fileNameSep to be configurable](https://github.com/log4js-node/streamroller/pull/67) - thanks [@laidaxian](https://github.com/laidaxian)
  - [Fix for fileNameSep affecting globally](https://github.com/log4js-node/streamroller/pull/79) - thanks [@peteriman](https://github.com/peteriman)
- [Fix for extra separator in filenames](https://github.com/log4js-node/streamroller/pull/75) - thanks [@peteriman](https://github.com/peteriman)
- [Moved to options.numBackups instead of options.daysToKeep](https://github.com/log4js-node/streamroller/pull/78) - thanks [@peteriman](https://github.com/peteriman)
- [Improved test case performance for fakeNow](https://github.com/log4js-node/streamroller/pull/76) - thanks [@peteriman](https://github.com/peteriman)
- <details><summary>Updated dependencies (click for details) - thanks <a href="https://github.com/peteriman">@peteriman</a></summary>
  
  - [package.json](https://github.com/log4js-node/streamroller/pull/70)
    - @commitlint/cli from 8.1.0 to 16.0.2
    - @commitlint/config-conventional from 8.1.0 to 16.0.0
    - @type/nodes 17.0.8
    - eslint from 6.0.1 to 8.6.0
    - mocha from 6.1.4 to 9.1.3
    - nyc from 14.1.1 to 15.1.0
  - [package-lock.json](https://github.com/log4js-node/streamroller/pull/71) 
    - @babel/compat-data from 7.16.4 to 7.16.8 
    - @babel/generator from 7.16.7 to 7.16.8
    - @babel/parser from 7.16.7 to 7.16.8
    - @babel/travers from 7.16.7 to 7.16.8
    - @babel/types from 7.16.7 to 7.16.8
  - [package-lock.json](https://github.com/log4js-node/streamroller/pull/77)
    - caniuse-lite from 1.0.30001298 to 1.0.30001299
    - electron-to-chromium from 1.4.39 to 1.4.44
  - [package.json](https://github.com/log4js-node/streamroller/pull/80)
    - date-format from 3.0.0 to 4.0.1
    - husky from 3.0.0 to 7.0.4
    - fs-extra from 8.1.0 to 10.0.0
</details>

## 2.2.4

- [Fix for incorrect filename matching](https://github.com/log4js-node/streamroller/pull/61) - thanks [@rnd-debug](https://github.com/rnd-debug)

## 2.2.3

- [Fix for unhandled promise rejection during cleanup](https://github.com/log4js-node/streamroller/pull/56)

## 2.2.2

- [Fix for overwriting current file when using date rotation](https://github.com/log4js-node/streamroller/pull/54)

## 2.2.1

- Fix for num to keep not working when date pattern is all digits (forgot to do a PR for this one)

## 2.2.0

- [Fallback to copy and truncate when file is busy](https://github.com/log4js-node/streamroller/pull/53)

## 2.1.0

- [Improve Windows support (closing streams)](https://github.com/log4js-node/streamroller/pull/52)

## 2.0.0

- [Remove support for node v6](https://github.com/log4js-node/streamroller/pull/44)
- [Replace lodash with native alternatives](https://github.com/log4js-node/streamroller/pull/45) - thanks [@devoto13](https://github.com/devoto13)
- [Simplify filename formatting and parsing](https://github.com/log4js-node/streamroller/pull/46)
- [Removed async lib from main code](https://github.com/log4js-node/streamroller/pull/47)
- [Fix timezone issues in tests](https://github.com/log4js-node/streamroller/pull/48) - thanks [@devoto13](https://github.com/devoto13)
- [Fix for flag values that need existing file size](https://github.com/log4js-node/streamroller/pull/49)
- [Refactor for better readability](https://github.com/log4js-node/streamroller/pull/50)
- [Removed async lib from test code](https://github.com/log4js-node/streamroller/pull/51)

## 1.0.6

- [Fix for overwriting old backup files](https://github.com/log4js-node/streamroller/pull/43)
- Updated lodash to 4.17.14

## 1.0.5

- [Updated dependencies](https://github.com/log4js-node/streamroller/pull/38)
- [Fix for initial file date when appending to existing file](https://github.com/log4js-node/streamroller/pull/40)

## 1.0.4

- [Fix for initial size when appending to existing file](https://github.com/log4js-node/streamroller/pull/35)

## 1.0.3

- [Fix for crash when pattern is all digits](https://github.com/log4js-node/streamroller/pull/33)

## 1.0.2

- is exactly the same as 1.0.1, due to me being an idiot and not pulling before I pushed

## Previous versions

Previous release details are available by browsing the milestones in github.
